Description Usage Arguments Value See Also
For each model M we compute the distances to all other
models. These distances are then ranked using the normalizing ranking
method rank.dist. The distance of one models set
to another model set is then the mean of the corresponding ranks.
1 2 | Models.dist.rank.local.mean(models, distance = RegressionResult.dist.default,
cores = 1L, logging = FALSE)
|
models |
the models records |
distance |
the
|
cores |
the number of CPU cores to use |
logging |
the logging setup, see |
an instance of dist
Models.dist.rank.aggregate
Models.dist.rank.global.mean
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.